# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-10-20 13:40
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Mark',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_pk', models.TextField(verbose_name='object ID')),
                ('marked_at', models.DateTimeField(default=django.utils.timezone.now, verbose_name='date/time marked')),
                ('comment', models.CharField(blank=True, max_length=256, null=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='content_type_set_for_mark', to='contenttypes.ContentType', verbose_name='content type')),
                ('marked_by', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='marks', to=settings.AUTH_USER_MODEL, verbose_name='user')),
            ],
            options={
                'ordering': ('marked_at',),
                'db_table': 'nano_mark',
                'get_latest_by': 'marked_at',
            },
        ),
        migrations.CreateModel(
            name='MarkType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32)),
                ('slug', models.SlugField(unique=True)),
                ('hide', models.BooleanField(default=False)),
                ('verify', models.BooleanField(default=False)),
                ('permanent', models.BooleanField(default=False)),
            ],
            options={
                'db_table': 'nano_mark_marktype',
            },
        ),
        migrations.AddField(
            model_name='mark',
            name='marktype',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mark.MarkType'),
        ),
    ]
