# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-10-20 13:37
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='PM',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('text', models.TextField()),
                ('text_formatted', models.TextField(editable=False)),
                ('text_type', models.CharField(default='plaintext', max_length=64)),
                ('subject', models.CharField(blank=True, default='', max_length=64)),
                ('sent', models.DateTimeField(default=django.utils.timezone.now, editable=False)),
                ('sender_deleted', models.BooleanField(default=False)),
                ('recipient_archived', models.BooleanField(default=False)),
                ('recipient_deleted', models.BooleanField(default=False)),
                ('recipient', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pms_received', to=settings.AUTH_USER_MODEL)),
                ('sender', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='pms_sent', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'nano_privmsg_pm',
            },
        ),
    ]
