# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-10-21 13:36
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Key',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=255)),
                ('group', models.SlugField(blank=True, max_length=32, null=True)),
                ('pub_date', models.DateTimeField(auto_now_add=True)),
                ('expires', models.DateTimeField(blank=True, null=True)),
                ('activated', models.DateTimeField(blank=True, null=True)),
                ('activated_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='activation_keys', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'get_latest_by': 'pub_date',
                'ordering': ('-pub_date',),
                'db_table': 'nano_activation_code',
            },
        ),
    ]
