# -*- coding: utf-8 -*-
# Generated by Django 1.9.13 on 2018-10-21 13:38
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Country',
            fields=[
                ('iso', models.CharField(max_length=2, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=128, verbose_name='Country name')),
            ],
            options={
                'verbose_name_plural': 'countries',
                'db_table': 'nano_country',
                'verbose_name': 'country',
            },
        ),
    ]
